summaryrefslogtreecommitdiff
path: root/src/lib/film.cc
diff options
context:
space:
mode:
authorCarl Hetherington <cth@carlh.net>2018-11-09 00:04:23 +0000
committerCarl Hetherington <cth@carlh.net>2018-11-09 00:04:23 +0000
commit1e77753ef4119b6d7df7d2255b1a1d8d6af951de (patch)
tree55d07cd2600939d883402d14d082a981627a1d3a /src/lib/film.cc
parent32dd3b31349f48adb21bf1923f076755705a508c (diff)
Allow specification of trusted devices by thumbprint rather thanv2.13.68
by full certificate.
Diffstat (limited to 'src/lib/film.cc')
-rw-r--r--src/lib/film.cc6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/lib/film.cc b/src/lib/film.cc
index 2ff02d799..426c7f81d 100644
--- a/src/lib/film.cc
+++ b/src/lib/film.cc
@@ -1259,7 +1259,7 @@ Film::frame_size () const
}
/** @param recipient KDM recipient certificate.
* @param trusted_devices Certificates of other trusted devices (can be empty).
* @param cpl_file CPL filename.
* @param from KDM from time expressed as a local time with an offset from UTC.
* @param until KDM to time expressed as a local time with an offset from UTC.
@@ -1271,7 +1271,7 @@ Film::frame_size () const
dcp::EncryptedKDM
Film::make_kdm (
dcp::Certificate recipient,
- vector<dcp::Certificate> trusted_devices,
+ vector<string> trusted_devices,
boost::filesystem::path cpl_file,
dcp::LocalTime from,
dcp::LocalTime until,
@@ -1357,7 +1357,7 @@ Film::make_kdms (
if (i->recipient) {
dcp::EncryptedKDM const kdm = make_kdm (
i->recipient.get(),
- i->trusted_devices,
+ i->trusted_device_thumbprints(),
cpl_file,
dcp::LocalTime (from, i->cinema->utc_offset_hour(), i->cinema->utc_offset_minute()),
dcp::LocalTime (until, i->cinema->utc_offset_hour(), i->cinema->utc_offset_minute()),
@@ -1259,7 +1259,7 @@ Film::frame_size () const
}
/** @param recipient KDM recipient certificate.
- * @param trusted_devices Certificates of other trusted devices (can be empty).
+ * @param trusted_devices Certificate thumbprints of other trusted devices (can be empty).
* @param cpl_file CPL filename.
* @param from KDM from time expressed as a local time with an offset from UTC.